@@ -47,6 +47,9 @@ pub struct ScanArg {
   #[clap(long, default_value = "rich", conflicts_with = "json")]
   report_style: ReportStyle,
 
+  /// Include rule metadata in the json output.
+  ///
+  /// This flags requires --json output. Default is false.
   #[clap(long, requires = "json")]
   include_metadata: bool,
 
@@ -301,7 +304,7 @@ fn match_rule_diff_on_file<T>(
   let diffs = matches
     .into_iter()
     .filter_map(|(rule, m)| {
-      let fix = rule.matcher.fixer.as_ref()?;
+      let fix = rule.matcher.fixer.first()?;
       let diff = Diff::generate(m, &rule.matcher, fix);
       Some((diff, rule))
     })
@@ -318,7 +321,7 @@ fn match_rule_on_file<T>(
   processor: &impl PrintProcessor<T>,
 ) -> Result<T> {
   let file = SimpleFile::new(path.to_string_lossy(), file_content);
-  let processed = if let Some(fixer) = &rule.matcher.fixer {
+  let processed = if let Some(fixer) = &rule.matcher.fixer.first() {
     let diffs = matches
       .into_iter()
       .map(|m| (Diff::generate(m, &rule.matcher, fixer), rule))
